//
//  RootViewController.m
//  Shopping
//
//  Created by Bill Pringle on 1/30/10.
//  Copyright __MyCompanyName__ 2010. All rights reserved.
//

#import <sqlite3.h>
#import "RootViewController.h"
#import "ShoppingAppDelegate.h"
#import "Item.h"


@implementation RootViewController


- (void)viewDidLoad {
    [super viewDidLoad];
	
	av = nil; // no item view yet
	avnav = nil;
	
	// get the application delegate
	appDelegate = (ShoppingAppDelegate *)
	[[UIApplication sharedApplication] delegate];
	self.title = @"Shopping List";

    self.navigationItem.rightBarButtonItem = 
	[[UIBarButtonItem alloc]
	 initWithBarButtonSystemItem:UIBarButtonSystemItemAdd 
	 target:self action:@selector(addButtonClicked:)];
}


-(void) addButtonClicked:(id)sender {
	if (!av)
	{ // first time for ItemView
		av = [[AddViewController alloc]
			  initWithNibName:@"AddViewController" bundle:nil];
	}
	if (!avnav)
	{
		avnav = [[UINavigationController alloc]
				 initWithRootViewController:av];
	}
	[self.navigationController 
	 presentModalViewController:avnav 
	 animated:YES];
}


- (void)viewWillAppear:(BOOL)animated {
    [super viewWillAppear:animated];

	[self.tableView reloadData];
}

/*
- (void)viewDidAppear:(BOOL)animated {
    [super viewDidAppear:animated];
}
*/
/*
- (void)viewWillDisappear:(BOOL)animated {
	[super viewWillDisappear:animated];
}
*/
/*
- (void)viewDidDisappear:(BOOL)animated {
	[super viewDidDisappear:animated];
}
*/

/*
 // Override to allow orientations other than the default portrait orientation.
- (BOOL)shouldAutorotateToInterfaceOrientation:(UIInterfaceOrientation)interfaceOrientation {
	// Return YES for supported orientations.
	return (interfaceOrientation == UIInterfaceOrientationPortrait);
}
 */

- (void)didReceiveMemoryWarning {
	// Releases the view if it doesn't have a superview.
    [super didReceiveMemoryWarning];
	
	// Release any cached data, images, etc that aren't in use.
}

- (void)viewDidUnload {
	// Release anything that can be recreated in viewDidLoad or on demand.
	// e.g. self.myOutlet = nil;
}


#pragma mark Table view methods

- (NSInteger)numberOfSectionsInTableView:(UITableView *)tableView {
    return 1;
}


// Customize the number of rows in the table view.
- (NSInteger)tableView:(UITableView *)tableView numberOfRowsInSection:(NSInteger)section {
    return [appDelegate.items count];
}


// Customize the appearance of table view cells.
- (UITableViewCell *)tableView:(UITableView *)tableView cellForRowAtIndexPath:(NSIndexPath *)indexPath {
    
    static NSString *CellIdentifier = @"Cell";
    
    UITableViewCell *cell = [tableView dequeueReusableCellWithIdentifier:CellIdentifier];
    if (cell == nil) {
        cell = [[[UITableViewCell alloc] initWithStyle:UITableViewCellStyleDefault reuseIdentifier:CellIdentifier] autorelease];
    }
    
	// Configure the cell.
	
	// get the item for this cell
	ShoppingAppDelegate *d = (ShoppingAppDelegate *) [[UIApplication sharedApplication] delegate];	
	Item *i = (Item *) [d.items objectAtIndex:indexPath.row];
	
	NSLog(@"Displaying row %d, need=%d", indexPath.row, i.need);
	
	if (i.need > 1)
	{
		cell.textLabel.text = [NSString stringWithFormat:@"%@ (%d)",
							   i.name, i.need];
	}
	else
	{
		cell.textLabel.text = i.name; // display item name in table cell
	}
	cell.detailTextLabel.text = i.notes;
	
	//
	// checkmark if item is needed
	// checkmark will toggle with subsequent selects
	//
	if (i.need>0)
	{ // item needed - display checkmark
		cell.accessoryType = UITableViewCellAccessoryCheckmark;
	}
	else
	{ // not needed no checkmark
		cell.accessoryType = UITableViewCellAccessoryNone;
	}
	
    return cell;
}




// Override to support row selection in the table view.
- (void)tableView:(UITableView *)tableView didSelectRowAtIndexPath:(NSIndexPath *)indexPath {	
	// get the item for this cell
	ShoppingAppDelegate *d = (ShoppingAppDelegate *) [[UIApplication sharedApplication] delegate];	
	Item *i = (Item *) [d.items objectAtIndex:indexPath.row];
	
	// deselect row and toggle selection checkmark
	[tableView deselectRowAtIndexPath:indexPath animated:NO]; // deselect row
	// get selected cell
	UITableViewCell *cell = [tableView cellForRowAtIndexPath:indexPath];
	
	//
	// toggle checkmark
	// if need is zero, assume now needed and set to one
	// if need positive, no longer needed - make negative
	// if need negative, still needed - make positive
	NSLog(@"Row %d selected - need=%d",indexPath.row, i.need);
	if (i.need==0)
	{ // item needed - set checkmark
		i.need = 1;
		cell.accessoryType = UITableViewCellAccessoryCheckmark;
	}
	else if (i.need < 0)
	{ // still needed
		i.need = -i.need; // reset original value
		cell.accessoryType = UITableViewCellAccessoryCheckmark;
	}
	else
	{
		i.need = -i.need;
		cell.accessoryType = UITableViewCellAccessoryNone;
	}
	NSLog(@"Need is now %d", i.need);
	
	[d updateItemAtIndexPath:indexPath]; // update database
}



/*
// Override to support conditional editing of the table view.
- (BOOL)tableView:(UITableView *)tableView canEditRowAtIndexPath:(NSIndexPath *)indexPath {
    // Return NO if you do not want the specified item to be editable.
    return YES;
}
*/


/*
// Override to support editing the table view.
- (void)tableView:(UITableView *)tableView commitEditingStyle:(UITableViewCellEditingStyle)editingStyle forRowAtIndexPath:(NSIndexPath *)indexPath {
    
    if (editingStyle == UITableViewCellEditingStyleDelete) {
        // Delete the row from the data source.
        [tableView deleteRowsAtIndexPaths:[NSArray arrayWithObject:indexPath] withRowAnimation:UITableViewRowAnimationFade];
    }   
    else if (editingStyle == UITableViewCellEditingStyleInsert) {
        // Create a new instance of the appropriate class, insert it into the array, and add a new row to the table view.
    }   
}
*/


/*
// Override to support rearranging the table view.
- (void)tableView:(UITableView *)tableView moveRowAtIndexPath:(NSIndexPath *)fromIndexPath toIndexPath:(NSIndexPath *)toIndexPath {
}
*/


/*
// Override to support conditional rearranging of the table view.
- (BOOL)tableView:(UITableView *)tableView canMoveRowAtIndexPath:(NSIndexPath *)indexPath {
    // Return NO if you do not want the item to be re-orderable.
    return YES;
}
*/


- (void)dealloc {
	[appDelegate release];
	[av release];
	[avnav release];
    [super dealloc];
}


@end

